geochemistrypi.data\_mining.model.func.algo\_classification package
===================================================================

Module contents
---------------

.. automodule:: geochemistrypi.data_mining.model.func.algo_classification
   :members:
   :undoc-members:
   :show-inheritance:
